import { EventEmitter, OnDestroy, OnInit, TemplateRef } from '@angular/core';
import { ClockFaceTime } from './models/clock-face-time.interface';
import { TimePeriod } from './models/time-period.enum';
import { Subscription } from 'rxjs';
import { NgxMaterialTimepickerService } from './services/ngx-material-timepicker.service';
import { TimeUnit } from './models/time-unit.enum';
import { AnimationEvent } from '@angular/animations';
import { NgxMaterialTimepickerEventService } from './services/ngx-material-timepicker-event.service';
import { TimepickerDirective } from './directives/ngx-timepicker.directive';
import { Moment } from 'moment';
export declare enum AnimationState {
    ENTER = "enter",
    LEAVE = "leave",
}
export declare class NgxMaterialTimepickerComponent implements OnInit, OnDestroy {
    private timepickerService;
    private eventService;
    selectedHour: ClockFaceTime;
    selectedMinute: ClockFaceTime;
    selectedPeriod: TimePeriod;
    timePeriod: typeof TimePeriod;
    timeUnit: typeof TimeUnit;
    activeTimeUnit: TimeUnit;
    isOpened: boolean;
    animationState: AnimationState;
    timepickerInput: TimepickerDirective;
    subscriptions: Subscription[];
    cancelBtnTmpl: TemplateRef<Node>;
    confirmBtnTmpl: TemplateRef<Node>;
    isEsc: boolean;
    timeSet: EventEmitter<string>;
    closed: EventEmitter<null>;
    constructor(timepickerService: NgxMaterialTimepickerService, eventService: NgxMaterialTimepickerEventService);
    readonly minTime: string | Moment;
    readonly maxTime: string | Moment;
    readonly minuteIncrements: number;
    readonly disabled: boolean;
    readonly format: number;
    ngOnInit(): void;
    /***
     * Register an input with this timepicker.
     * input - The timepicker input to register with this timepicker
     */
    registerInput(input: TimepickerDirective): void;
    onHourChange(hour: ClockFaceTime): void;
    onMinuteChange(minute: ClockFaceTime): void;
    changePeriod(period: TimePeriod): void;
    changeTimeUnit(unit: TimeUnit): void;
    setTime(): void;
    setDefaultTime(time: string): void;
    open(): void;
    close(): void;
    animationDone(event: AnimationEvent): void;
    onKeydown(e: KeyboardEvent): void;
    ngOnDestroy(): void;
}
